Loading iXBRL Viewer

# Fact Properties

# Footnote Properties

Reset

### Filter

Concept Type
Fact Value
Hidden Facts
Visible Facts

### Period

### Namespaces

### Units

### Scales

### Dimension Type

### Calculations

? matching concept(s)

No Fact Selected

Hidden Fact
Concealed Fact

### Anchoring

#### Wider anchor

#### Narrower anchors

### References

### Calculations

### Footnotes

### Associated Facts

### Sections

### Associated facts

Fact Search

Please enter some search terms

Fact Search

Please wait - building index...

Outline Unavailable

### Fact Summary

Total Facts:

### Tag Summary

Namespace | Primary Items | Dimensions | Members | Total
--- | --- | --- | --- | ---
Total

### File Summary

Inline Documents

Schemas

Presentation Linkbases

Calculation Linkbases

Definition Linkbases

Label Linkbases

Reference Linkbases

Other Linkbases

## Validation results

Severity | Code | Message

##

Show text only

##

+
-